@@ -1,23 +1,15 @@
-# Copyright 2021-2022 The Memphis Authors
-# Licensed under the MIT License (the "License");
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
+#  Copyright 2021-2022 The Memphis Authors
+#  Licensed under the Apache License, Version 2.0 (the “License”);
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
+#  http://www.apache.org/licenses/LICENSE-2.0
 
-# This license limiting reselling the software itself "AS IS".
-
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an “AS IS” BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License
 
 import random
 import json
@@ -271,8 +263,10 @@ class Factory:
                 "factory_name":self.name
             }
             factory_name = json.dumps(nameReq, indent=2).encode('utf-8')
-            await self.connection.broker_connection.publish('$memphis_factory_destructions', factory_name)
-
+            res = await self.connection.broker_manager.request('$memphis_factory_destructions', factory_name)
+            error = res.data.decode('utf-8')
+            if error != "" and not "not exist" in error:
+                raise Exception(error)
         except Exception as e:
             raise Exception(e)
  
@@ -291,8 +285,10 @@ class Station:
                 "station_name":self.name
             }
             station_name = json.dumps(nameReq, indent=2).encode('utf-8')
-            await self.connection.broker_connection.publish('$memphis_station_destructions', station_name)
-
+            res = await self.connection.broker_manager.request('$memphis_station_destructions', station_name)
+            error = res.data.decode('utf-8')
+            if error != "" and not "not exist" in error:
+                raise Exception(error)
         except Exception as e:
             raise Exception(e)
 
@@ -328,11 +324,14 @@ class Producer:
         try:
             destroyProducerReq = {
                 "name": self.producer_name,
-                "station_name":self.station_name
+                "station_name": self.station_name
             }
-            producer_name = json.dumps(destroyProducerReq, indent=2).encode('utf-8')
-            await self.connection.broker_connection.publish('$memphis_producer_destructions', producer_name)
-
+            
+            producer_name = json.dumps(destroyProducerReq).encode('utf-8')
+            res = await self.connection.broker_manager.request('$memphis_producer_destructions', producer_name)
+            error = res.data.decode('utf-8')
+            if error != "" and not "not exist" in error:
+                raise Exception(error)
         except Exception as e:
             raise Exception(e)
 
@@ -402,8 +401,10 @@ class Consumer:
                 "station_name":self.station_name
             }
             consumer_name = json.dumps(destroyConsumerReq, indent=2).encode('utf-8')
-            await self.connection.broker_connection.publish('$memphis_consumer_destructions', consumer_name)
-
+            res = await self.connection.broker_manager.request('$memphis_consumer_destructions', consumer_name)
+            error = res.data.decode('utf-8')
+            if error != "" and not "not exist" in error:
+                raise Exception(error)
         except Exception as e:
             raise Exception(e)
 
